﻿using System.Collections.Generic;
using GalaSoft.MvvmLight;
using HelloWorld.Model;

namespace HelloWorld.ViewModel
{
    /// <summary>
    /// This class contains properties that the main View can data bind to.
    /// <para>
    /// See http://www.galasoft.ch/mvvm
    /// </para>
    /// </summary>
    public class MainViewModel : ViewModelBase
    {
        private List<TileItem> _tileList = new List<TileItem>()
            {
                new TileItem()
                    {
                        ImageUri = "/Images/Desert1.png",
                        Title = "Desert1",
                        Message = "It's real yummy. Try it!!",
                        GroupTag = "Group1"
                    },
                new TileItem()
                    {
                        ImageUri = "/Images/Desert2.png",
                        Title = "Desert2",
                        Notification = "Avail Disc",
                        GroupTag = "Group2"
                    },
                new TileItem()
                    {
                        ImageUri = "/Images/Desert3.png",
                        Title = "Desert3",
                        Notification = "No Disc",
                        Message = "It's real yummy. Try it!!",
                        GroupTag = "Group1"
                    },
                new TileItem()
                    {
                        ImageUri = "/Images/Desert4.png",
                        Title = "Desert4",
                        Notification = "No Disc",
                        GroupTag = "Group2"
                    }
            };

        private List<ListItem> _items = new List<ListItem>()
            {
                new ListItem()
                    {
                        LineOne = "Desert1",
                        LineTwo = "Yummy!"
                    },
                new ListItem()
                    {
                        LineOne = "Desert2",
                        LineTwo = "Good!"
                    },
                new ListItem()
                    {
                        LineOne = "Desert3",
                        LineTwo = "Yummy!"
                    }
            };

        private readonly IDataService _dataService;

        /// <summary>
        /// The <see cref="WelcomeTitle" /> property's name.
        /// </summary>
        public const string WelcomeTitlePropertyName = "WelcomeTitle";

        private string _welcomeTitle = string.Empty;

        /// <summary>
        /// Gets the WelcomeTitle property.
        /// Changes to that property's value raise the PropertyChanged event. 
        /// </summary>
        public string WelcomeTitle
        {
            get { return _welcomeTitle; }

            set
            {
                if (_welcomeTitle == value)
                {
                    return;
                }

                _welcomeTitle = value;
                RaisePropertyChanged(WelcomeTitlePropertyName);
            }
        }

        public List<TileItem> TileList
        {
            get { return _tileList; }
            set { _tileList = value; }
        }

        public List<ListItem> Items
        {
            get { return _items; }
            set { _items = value; }
        }

        /// <summary>
        /// Initializes a new instance of the MainViewModel class.
        /// </summary>
        public MainViewModel(IDataService dataService)
        {
            _dataService = dataService;
            _dataService.GetData(
                (item, error) =>
                    {
                        if (error != null)
                        {
                            // Report error here
                            return;
                        }

                        WelcomeTitle = item.Title;
                    });
        }

        ////public override void Cleanup()
        ////{
        ////    // Clean up if needed

        ////    base.Cleanup();
        ////}
    }

    public class ListItem
    {
        public string LineOne { get; set; }

        public string LineTwo { get; set; }
    }

    public class TileItem
    {
        public string ImageUri { get; set; }

        public string Title { get; set; }

        public string Notification { get; set; }

        public bool DisplayNotification
        {
            get { return !string.IsNullOrEmpty(this.Notification); }
        }

        public string Message { get; set; }

        public string GroupTag { get; set; }

        public bool IsFrozen { get; set; }
    }
}